@@ -1,3 +1,6 @@
+/* spiro.h
+libspiro - A sharable library of Spiro formula and functions.
+*/
 #ifndef _SPIRO_H
 #define _SPIRO_H
 
@@ -29,16 +32,26 @@ struct spiro_seg_s {
 typedef struct spiro_seg_s spiro_seg;
 
 spiro_seg *
-run_spiro(const spiro_cp *src, int n);
+run_spiro(const spiro_cp *src, int n); /* deprecated */
 
 void
 free_spiro(spiro_seg *s);
 
 void
-spiro_to_bpath(const spiro_seg *s, int n, bezctx *bc);
+spiro_to_bpath(const spiro_seg *s, int n, bezctx *bc); /* deprecated */
 
 double get_knot_th(const spiro_seg *s, int i);
 
+spiro_seg *
+run_spiro0(const spiro_cp *src, double *dm, int ncq, int n);
+
+int
+spiro_to_bpath0(const spiro_cp *src, const spiro_seg *s,
+		double *dm, int ncq, int n, bezctx *bc);
+ 
+const char *
+LibSpiroVersion(void);
+
 #ifdef __cplusplus
 }
 #endif
